@@ -1,13 +1,9 @@
-"""
-widget for django
-"""
+"""widget for django."""
 
 from django.forms import ClearableFileInput
 
 
 class FileInputWidget(ClearableFileInput):
-    """
-    file input widget
-    """
+    """file input widget."""
 
     template_name = "file_validator/file_input_widget.html"
